@@ -1,11 +1,10 @@
-import pytest
 from mock import Mock
 import os
 import threading
 import sys
 import pip
 
-from qaseio.commons import QaseUtils  # Replace with the actual import
+from qaseio.commons import QaseUtils
 
 def test_build_tree():
     # Mocking item objects
